summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/planner_ixselect.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/query/planner_ixselect.h')
-rw-r--r--src/mongo/db/query/planner_ixselect.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/query/planner_ixselect.h b/src/mongo/db/query/planner_ixselect.h
index 01123e652b8..e2591ab3650 100644
--- a/src/mongo/db/query/planner_ixselect.h
+++ b/src/mongo/db/query/planner_ixselect.h
@@ -152,9 +152,9 @@ public:
const std::vector<IndexEntry>& relevantIndices);
/**
* Check if this match expression is a leaf and is supported by an allPaths index.
*/
- static bool nodeIsSupportedByAllPathsIndex(const MatchExpression* queryExpr);
+ static bool nodeIsSupportedByWildcardIndex(const MatchExpression* queryExpr);
/*
* Return true if the given match expression can use a sparse index, false otherwise. This will
@@ -245,14 +245,14 @@ private:
const std::vector<IndexEntry>& indices);
/**
* This function strips RelevantTag assignments to expanded 'allPaths' indexes, in cases where
* the assignment is incompatible with the query.
*
* Specifically, if the query has a TEXT node with both 'text' and 'allPaths' indexes present,
* then the 'allPaths' index will mark itself as relevant to the '_fts' path reported by the
* TEXT node. We therefore remove any such misassigned 'allPaths' tags here.
*/
- static void stripInvalidAssignmentsToAllPathsIndexes(MatchExpression* root,
+ static void stripInvalidAssignmentsToWildcardIndexes(MatchExpression* root,
const std::vector<IndexEntry>& indices);
/**
@@ -152,9 +152,9 @@ public:
const std::vector<IndexEntry>& relevantIndices);
/**
- * Check if this match expression is a leaf and is supported by an allPaths index.
+ * Check if this match expression is a leaf and is supported by a wildcard index.
*/
@@ -245,14 +245,14 @@ private:
const std::vector<IndexEntry>& indices);
/**
- * This function strips RelevantTag assignments to expanded 'allPaths' indexes, in cases where
+ * This function strips RelevantTag assignments to expanded 'wildcard' indexes, in cases where
* the assignment is incompatible with the query.
*
@@ -245,14 +245,14 @@ private:
* the assignment is incompatible with the query.
*
- * Specifically, if the query has a TEXT node with both 'text' and 'allPaths' indexes present,
- * then the 'allPaths' index will mark itself as relevant to the '_fts' path reported by the
- * TEXT node. We therefore remove any such misassigned 'allPaths' tags here.
+ * Specifically, if the query has a TEXT node with both 'text' and 'wildcard' indexes present,
+ * then the 'wildcard' index will mark itself as relevant to the '_fts' path reported by the
+ * TEXT node. We therefore remove any such misassigned 'wildcard' tags here.
*/